import { __decorate } from "tslib";
import { Connect, DatasourceDefaults } from '@genesislcap/foundation-comms';
import { customElement, observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { ReportingHomeStyles as styles } from './reporting-home-styles';
import { ReportingHomeTemplate as template } from './reporting-home-template';
import { ReportingEventListeners } from './types';
const name = 'reporting-home';
let ReportingHome = class ReportingHome extends FoundationElement {
    constructor() {
        super(...arguments);
        this.fields = [];
        this.selectedRows = [];
        this.activeReport = {};
        this.notifications = [];
    }
    async enter(phase) {
        this.datasourceSettings = {
            maxRows: phase.route.settings?.maxRows ?? DatasourceDefaults.MAX_ROWS_250,
            maxView: phase.route.settings?.maxView ?? DatasourceDefaults.MAX_VIEW_1000,
        };
    }
    async connectedCallback() {
        super.connectedCallback();
        this.reportsGrid.addEventListener('rowSelectionEvent', (e) => {
            this.selectedRows = e.detail.selectedRows();
        });
        this.addEventListener(ReportingEventListeners.notify, (e) => {
            this.notifications = [...this.notifications, e.detail];
        });
        this.addEventListener(ReportingEventListeners.listReports, (e) => {
            this.setPageTab('list-reports');
            this.activeReport = {};
        });
        this.reportsGrid.addEventListener(ReportingEventListeners.runReport, (e) => {
            this.run(e.detail);
        });
        this.reportsGrid.addEventListener(ReportingEventListeners.editReport, (e) => {
            this.edit(e.detail);
        });
    }
    // TODO: use const for tab identifiers
    create() {
        this.activeReport = {};
        this.setPageTab('create-edit-report');
    }
    edit(rowData) {
        this.activeReport = {
            ...rowData,
            REPORT_COLUMNS: JSON.parse(rowData['REPORT_COLUMNS']),
        };
        this.setPageTab('create-edit-report');
    }
    async run(rowData) {
        this.activeReport = {
            ...rowData,
            REPORT_COLUMNS: JSON.parse(rowData['REPORT_COLUMNS']),
        };
        this.setPageTab('run-report');
    }
    setPageTab(tab) {
        this.tabs.activeid = tab;
    }
    async getFields(resourceName) {
        const temp = await this.connect.getMetadata(resourceName);
        for (let i = 0; i < temp.FIELD.length; i += 1) {
            this.fields.push(temp.FIELD[i].NAME);
        }
        this.listBox.hidden = false;
    }
};
__decorate([
    Connect
], ReportingHome.prototype, "connect", void 0);
__decorate([
    observable
], ReportingHome.prototype, "fields", void 0);
__decorate([
    observable
], ReportingHome.prototype, "selectedRows", void 0);
__decorate([
    observable
], ReportingHome.prototype, "activeReport", void 0);
__decorate([
    observable
], ReportingHome.prototype, "notifications", void 0);
__decorate([
    observable
], ReportingHome.prototype, "datasourceSettings", void 0);
ReportingHome = __decorate([
    customElement({
        name,
        template,
        styles,
    })
], ReportingHome);
export { ReportingHome };
